@@ -1,17 +1,18 @@
 #-*- coding:utf-8 -*-
 
+from .base import Comparer
 from .base import Condition
 from ..torrentstatus import TorrentStatus
 
 class SeedingTimeCondition(Condition):
-    def __init__(self, st):
+    def __init__(self, st, comp = Comparer.GT):
         Condition.__init__(self) # Initialize remain and remove list
         self._seeding_time = st
+        self._comparer = comp
 
     def apply(self, torrents):
         for torrent in torrents:
-            if torrent.status == TorrentStatus.Uploading and \
-                torrent.seeding_time > self._seeding_time:
-                self.remove.append(torrent)
+            if self.compare(torrent.seeding_time, self._seeding_time, self._comparer):
+                self.remove.add(torrent)
             else:
-                self.remain.append(torrent)
\ No newline at end of file
+                self.remain.add(torrent)
\ No newline at end of file
